Overview
========

This automates development tasks - creates setup.py, builds documentation, manages releases.

Installation
============

To install::

    pip install autogen

For full documentation see https://simonm3.gitlab.io/autogen/index.html